@@ -1,9 +1,12 @@
-C Output from Public domain Ratfor, version 1.0
-      subroutine circen(i,j,k,x0,y0,x,y,ntot,eps,collin,nerror)
+C Output from Public domain Ratfor, version 1.03
+      subroutine circen(i,j,k,x0,y0,x,y,ntot,eps,collin)
       implicit double precision(a-h,o-z)
       dimension x(-3:ntot), y(-3:ntot), xt(3), yt(3)
+      dimension indv(3)
+      dimension xtmp(1)
+      dimension ndi(1)
       logical collin
-      nerror = -1
+      ndi(1) = 0
       xt(1) = x(i)
       yt(1) = y(i)
       xt(2) = x(j)
@@ -30,8 +33,15 @@ C Output from Public domain Ratfor, version 1.0
       if(collin)then
       alpha = a*c+b*d
       if(alpha.gt.0)then
-      nerror = 3
-      return
+      indv(1) = i
+      indv(2) = j
+      indv(3) = k
+      call intpr("Point numbers:",-1,indv,3)
+      xtmp(1) = alpha
+      call dblepr("Test value:",-1,xtmp,1)
+      call intpr("Points are collinear but in the wrong order.",-1,ndi,0
+     *)
+      call rexit("Bailing out of circen.")
       endif
       return
       endif
